@@ -21,6 +21,7 @@
 #pragma once
 
 #include <thrust/detail/config.h>
+
 #include <thrust/detail/execution_policy.h>
 #include <thrust/pair.h>
 
@@ -33,7 +34,8 @@ THRUST_NAMESPACE_BEGIN
  *  \return The smaller element.
  *
  *  \tparam T is convertible to \p BinaryPredicate's first argument type and to its second argument type.
- *  \tparam BinaryPredicate is a model of <a href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">BinaryPredicate</a>.
+ *  \tparam BinaryPredicate is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">BinaryPredicate</a>.
  *
  *  The following code snippet demonstrates how to use \p min to compute the smaller of two
  *  key-value objects.
@@ -68,17 +70,16 @@ THRUST_NAMESPACE_BEGIN
  *  \note Returns the first argument when the arguments are equivalent.
  *  \see max
  */
-template<typename T, typename BinaryPredicate>
-THRUST_HOST_DEVICE
-  T min THRUST_PREVENT_MACRO_SUBSTITUTION (const T &lhs, const T &rhs, BinaryPredicate comp);
-
+template <typename T, typename BinaryPredicate>
+THRUST_HOST_DEVICE T min THRUST_PREVENT_MACRO_SUBSTITUTION(const T& lhs, const T& rhs, BinaryPredicate comp);
 
 /*! This version of \p min returns the smaller of two values.
  *  \param lhs The first value to compare.
  *  \param rhs The second value to compare.
  *  \return The smaller element.
  *
- *  \tparam T is a model of <a href="https://en.cppreference.com/w/cpp/named_req/LessThanComparable">LessThan Comparable</a>.
+ *  \tparam T is a model of <a href="https://en.cppreference.com/w/cpp/named_req/LessThanComparable">LessThan
+ * Comparable</a>.
  *
  *  The following code snippet demonstrates how to use \p min to compute the smaller of two
  *  integers.
@@ -97,10 +98,8 @@ THRUST_HOST_DEVICE
  *  \note Returns the first argument when the arguments are equivalent.
  *  \see max
  */
-template<typename T>
-THRUST_HOST_DEVICE
-  T min THRUST_PREVENT_MACRO_SUBSTITUTION (const T &lhs, const T &rhs);
-
+template <typename T>
+THRUST_HOST_DEVICE T min THRUST_PREVENT_MACRO_SUBSTITUTION(const T& lhs, const T& rhs);
 
 /*! This version of \p max returns the larger of two values, given a comparison operation.
  *  \param lhs The first value to compare.
@@ -109,7 +108,8 @@ THRUST_HOST_DEVICE
  *  \return The larger element.
  *
  *  \tparam T is convertible to \p BinaryPredicate's first argument type and to its second argument type.
- *  \tparam BinaryPredicate is a model of <a href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">BinaryPredicate</a>.
+ *  \tparam BinaryPredicate is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">BinaryPredicate</a>.
  *
  *  The following code snippet demonstrates how to use \p max to compute the larger of two
  *  key-value objects.
@@ -144,17 +144,16 @@ THRUST_HOST_DEVICE
  *  \note Returns the first argument when the arguments are equivalent.
  *  \see min
  */
-template<typename T, typename BinaryPredicate>
-THRUST_HOST_DEVICE
-  T max THRUST_PREVENT_MACRO_SUBSTITUTION (const T &lhs, const T &rhs, BinaryPredicate comp);
-
+template <typename T, typename BinaryPredicate>
+THRUST_HOST_DEVICE T max THRUST_PREVENT_MACRO_SUBSTITUTION(const T& lhs, const T& rhs, BinaryPredicate comp);
 
 /*! This version of \p max returns the larger of two values.
  *  \param lhs The first value to compare.
  *  \param rhs The second value to compare.
  *  \return The larger element.
  *
- *  \tparam T is a model of <a href="https://en.cppreference.com/w/cpp/named_req/LessThanComparable">LessThan Comparable</a>.
+ *  \tparam T is a model of <a href="https://en.cppreference.com/w/cpp/named_req/LessThanComparable">LessThan
+ * Comparable</a>.
  *
  *  The following code snippet demonstrates how to use \p max to compute the larger of two
  *  integers.
@@ -173,10 +172,8 @@ THRUST_HOST_DEVICE
  *  \note Returns the first argument when the arguments are equivalent.
  *  \see min
  */
-template<typename T>
-THRUST_HOST_DEVICE
-  T max THRUST_PREVENT_MACRO_SUBSTITUTION (const T &lhs, const T &rhs);
-
+template <typename T>
+THRUST_HOST_DEVICE T max THRUST_PREVENT_MACRO_SUBSTITUTION(const T& lhs, const T& rhs);
 
 /*! \addtogroup reductions
  *  \{
@@ -205,9 +202,9 @@ THRUST_HOST_DEVICE
  *  \return An iterator pointing to the smallest element of the range <tt>[first, last)</tt>,
  *          if it is not an empty range; \p last, otherwise.
  *
- *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward Iterator</a>,
- *          and \c ForwardIterator's \c value_type is a model of
- *          <a href="https://en.cppreference.com/w/cpp/named_req/LessThanComparable">LessThan Comparable</a>.
+ *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward
+ * Iterator</a>, and \c ForwardIterator's \c value_type is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/LessThanComparable">LessThan Comparable</a>.
  *
  *  \code
  *  #include <thrust/extrema.h>
@@ -220,12 +217,11 @@ THRUST_HOST_DEVICE
  *  // *result is 0
  *  \endcode
  *
- *  \see https://en.cppreference.com/w/cpp/algorithm/min_element 
+ *  \see https://en.cppreference.com/w/cpp/algorithm/min_element
  */
-template<typename DerivedPolicy, typename ForwardIterator>
-THRUST_HOST_DEVICE
-ForwardIterator min_element(const thrust::detail::execution_policy_base<DerivedPolicy> &exec, ForwardIterator first, ForwardIterator last);
-
+template <typename DerivedPolicy, typename ForwardIterator>
+THRUST_HOST_DEVICE ForwardIterator min_element(
+  const thrust::detail::execution_policy_base<DerivedPolicy>& exec, ForwardIterator first, ForwardIterator last);
 
 /*! \p min_element finds the smallest element in the range <tt>[first, last)</tt>.
  *  It returns the first iterator \c i in <tt>[first, last)</tt>
@@ -244,9 +240,9 @@ ForwardIterator min_element(const thrust::detail::execution_policy_base<DerivedP
  *  \return An iterator pointing to the smallest element of the range <tt>[first, last)</tt>,
  *          if it is not an empty range; \p last, otherwise.
  *
- *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward Iterator</a>,
- *          and \c ForwardIterator's \c value_type is a model of
- *          <a href="https://en.cppreference.com/w/cpp/named_req/LessThanComparable">LessThan Comparable</a>.
+ *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward
+ * Iterator</a>, and \c ForwardIterator's \c value_type is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/LessThanComparable">LessThan Comparable</a>.
  *
  *  \code
  *  #include <thrust/extrema.h>
@@ -258,12 +254,11 @@ ForwardIterator min_element(const thrust::detail::execution_policy_base<DerivedP
  *  // *result is 0
  *  \endcode
  *
- *  \see https://en.cppreference.com/w/cpp/algorithm/min_element 
+ *  \see https://en.cppreference.com/w/cpp/algorithm/min_element
  */
 template <typename ForwardIterator>
 ForwardIterator min_element(ForwardIterator first, ForwardIterator last);
 
-
 /*! \p min_element finds the smallest element in the range <tt>[first, last)</tt>.
  *  It returns the first iterator \c i in <tt>[first, last)</tt>
  *  such that no other iterator in <tt>[first, last)</tt> points to a value smaller
@@ -286,10 +281,10 @@ ForwardIterator min_element(ForwardIterator first, ForwardIterator last);
  *          if it is not an empty range; \p last, otherwise.
  *
  *  \tparam DerivedPolicy The name of the derived execution policy.
- *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward Iterator</a>,
- *          and \p ForwardIterator's \c value_type is convertible to both \p comp's
- *          \c first_argument_type and \c second_argument_type.
- *  \tparam BinaryPredicate is a model of <a href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">Binary Predicate</a>.
+ *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward
+ * Iterator</a>, and \p ForwardIterator's \c value_type is convertible to both \p comp's \c first_argument_type and \c
+ * second_argument_type. \tparam BinaryPredicate is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">Binary Predicate</a>.
  *
  *  The following code snippet demonstrates how to use \p min_element to find the smallest element
  *  of a collection of key-value pairs using the \p thrust::host execution policy for parallelization:
@@ -323,12 +318,14 @@ ForwardIterator min_element(ForwardIterator first, ForwardIterator last);
  *  // *smallest == {0,7}
  *  \endcode
  *
- *  \see https://en.cppreference.com/w/cpp/algorithm/min_element 
+ *  \see https://en.cppreference.com/w/cpp/algorithm/min_element
  */
-template<typename DerivedPolicy, typename ForwardIterator, typename BinaryPredicate>
-THRUST_HOST_DEVICE
-ForwardIterator min_element(const thrust::detail::execution_policy_base<DerivedPolicy> &exec, ForwardIterator first, ForwardIterator last, BinaryPredicate comp);
-
+template <typename DerivedPolicy, typename ForwardIterator, typename BinaryPredicate>
+THRUST_HOST_DEVICE ForwardIterator min_element(
+  const thrust::detail::execution_policy_base<DerivedPolicy>& exec,
+  ForwardIterator first,
+  ForwardIterator last,
+  BinaryPredicate comp);
 
 /*! \p min_element finds the smallest element in the range <tt>[first, last)</tt>.
  *  It returns the first iterator \c i in <tt>[first, last)</tt>
@@ -348,10 +345,10 @@ ForwardIterator min_element(const thrust::detail::execution_policy_base<DerivedP
  *  \return An iterator pointing to the smallest element of the range <tt>[first, last)</tt>,
  *          if it is not an empty range; \p last, otherwise.
  *
- *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward Iterator</a>,
- *          and \p ForwardIterator's \c value_type is convertible to both \p comp's
- *          \c first_argument_type and \c second_argument_type.
- *  \tparam BinaryPredicate is a model of <a href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">Binary Predicate</a>.
+ *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward
+ * Iterator</a>, and \p ForwardIterator's \c value_type is convertible to both \p comp's \c first_argument_type and \c
+ * second_argument_type. \tparam BinaryPredicate is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">Binary Predicate</a>.
  *
  *  The following code snippet demonstrates how to use \p min_element to find the smallest element
  *  of a collection of key-value pairs.
@@ -383,12 +380,10 @@ ForwardIterator min_element(const thrust::detail::execution_policy_base<DerivedP
  *  // *smallest == {0,7}
  *  \endcode
  *
- *  \see https://en.cppreference.com/w/cpp/algorithm/min_element 
+ *  \see https://en.cppreference.com/w/cpp/algorithm/min_element
  */
 template <typename ForwardIterator, typename BinaryPredicate>
-ForwardIterator min_element(ForwardIterator first, ForwardIterator last,
-                            BinaryPredicate comp);
-
+ForwardIterator min_element(ForwardIterator first, ForwardIterator last, BinaryPredicate comp);
 
 /*! \p max_element finds the largest element in the range <tt>[first, last)</tt>.
  *  It returns the first iterator \c i in <tt>[first, last)</tt>
@@ -411,9 +406,9 @@ ForwardIterator min_element(ForwardIterator first, ForwardIterator last,
  *          if it is not an empty range; \p last, otherwise.
  *
  *  \tparam A Thrust backend system.
- *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward Iterator</a>,
- *          and \c ForwardIterator's \c value_type is a model of
- *          <a href="https://en.cppreference.com/w/cpp/named_req/LessThanComparable">LessThan Comparable</a>.
+ *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward
+ * Iterator</a>, and \c ForwardIterator's \c value_type is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/LessThanComparable">LessThan Comparable</a>.
  *
  *  \code
  *  #include <thrust/extrema.h>
@@ -425,12 +420,11 @@ ForwardIterator min_element(ForwardIterator first, ForwardIterator last,
  *  // *result == 3
  *  \endcode
  *
- *  \see https://en.cppreference.com/w/cpp/algorithm/max_element 
+ *  \see https://en.cppreference.com/w/cpp/algorithm/max_element
  */
-template<typename DerivedPolicy, typename ForwardIterator>
-THRUST_HOST_DEVICE
-ForwardIterator max_element(const thrust::detail::execution_policy_base<DerivedPolicy> &exec, ForwardIterator first, ForwardIterator last);
-
+template <typename DerivedPolicy, typename ForwardIterator>
+THRUST_HOST_DEVICE ForwardIterator max_element(
+  const thrust::detail::execution_policy_base<DerivedPolicy>& exec, ForwardIterator first, ForwardIterator last);
 
 /*! \p max_element finds the largest element in the range <tt>[first, last)</tt>.
  *  It returns the first iterator \c i in <tt>[first, last)</tt>
@@ -449,9 +443,9 @@ ForwardIterator max_element(const thrust::detail::execution_policy_base<DerivedP
  *  \return An iterator pointing to the largest element of the range <tt>[first, last)</tt>,
  *          if it is not an empty range; \p last, otherwise.
  *
- *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward Iterator</a>,
- *          and \c ForwardIterator's \c value_type is a model of
- *          <a href="https://en.cppreference.com/w/cpp/named_req/LessThanComparable">LessThan Comparable</a>.
+ *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward
+ * Iterator</a>, and \c ForwardIterator's \c value_type is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/LessThanComparable">LessThan Comparable</a>.
  *
  *  \code
  *  #include <thrust/extrema.h>
@@ -462,12 +456,11 @@ ForwardIterator max_element(const thrust::detail::execution_policy_base<DerivedP
  *  // *result == 3
  *  \endcode
  *
- *  \see https://en.cppreference.com/w/cpp/algorithm/max_element 
+ *  \see https://en.cppreference.com/w/cpp/algorithm/max_element
  */
 template <typename ForwardIterator>
 ForwardIterator max_element(ForwardIterator first, ForwardIterator last);
 
-
 /*! \p max_element finds the largest element in the range <tt>[first, last)</tt>.
  *  It returns the first iterator \c i in <tt>[first, last)</tt>
  *  such that no other iterator in <tt>[first, last)</tt> points to a value larger
@@ -490,10 +483,10 @@ ForwardIterator max_element(ForwardIterator first, ForwardIterator last);
  *          if it is not an empty range; \p last, otherwise.
  *
  *  \tparam DerivedPolicy The name of the derived execution policy.
- *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward Iterator</a>,
- *          and \p ForwardIterator's \c value_type is convertible to both \p comp's
- *          \c first_argument_type and \c second_argument_type.
- *  \tparam BinaryPredicate is a model of <a href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">Binary Predicate</a>.
+ *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward
+ * Iterator</a>, and \p ForwardIterator's \c value_type is convertible to both \p comp's \c first_argument_type and \c
+ * second_argument_type. \tparam BinaryPredicate is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">Binary Predicate</a>.
  *
  *  The following code snippet demonstrates how to use \p max_element to find the largest element
  *  of a collection of key-value pairs using the \p thrust::host execution policy for parallelization.
@@ -527,12 +520,14 @@ ForwardIterator max_element(ForwardIterator first, ForwardIterator last);
  *  // *largest == {6,1}
  *  \endcode
  *
- *  \see https://en.cppreference.com/w/cpp/algorithm/max_element 
+ *  \see https://en.cppreference.com/w/cpp/algorithm/max_element
  */
-template<typename DerivedPolicy, typename ForwardIterator, typename BinaryPredicate>
-THRUST_HOST_DEVICE
-ForwardIterator max_element(const thrust::detail::execution_policy_base<DerivedPolicy> &exec, ForwardIterator first, ForwardIterator last, BinaryPredicate comp);
-
+template <typename DerivedPolicy, typename ForwardIterator, typename BinaryPredicate>
+THRUST_HOST_DEVICE ForwardIterator max_element(
+  const thrust::detail::execution_policy_base<DerivedPolicy>& exec,
+  ForwardIterator first,
+  ForwardIterator last,
+  BinaryPredicate comp);
 
 /*! \p max_element finds the largest element in the range <tt>[first, last)</tt>.
  *  It returns the first iterator \c i in <tt>[first, last)</tt>
@@ -552,10 +547,10 @@ ForwardIterator max_element(const thrust::detail::execution_policy_base<DerivedP
  *  \return An iterator pointing to the largest element of the range <tt>[first, last)</tt>,
  *          if it is not an empty range; \p last, otherwise.
  *
- *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward Iterator</a>,
- *          and \p ForwardIterator's \c value_type is convertible to both \p comp's
- *          \c first_argument_type and \c second_argument_type.
- *  \tparam BinaryPredicate is a model of <a href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">Binary Predicate</a>.
+ *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward
+ * Iterator</a>, and \p ForwardIterator's \c value_type is convertible to both \p comp's \c first_argument_type and \c
+ * second_argument_type. \tparam BinaryPredicate is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">Binary Predicate</a>.
  *
  *  The following code snippet demonstrates how to use \p max_element to find the largest element
  *  of a collection of key-value pairs.
@@ -587,12 +582,10 @@ ForwardIterator max_element(const thrust::detail::execution_policy_base<DerivedP
  *  // *largest == {6,1}
  *  \endcode
  *
- *  \see https://en.cppreference.com/w/cpp/algorithm/max_element 
+ *  \see https://en.cppreference.com/w/cpp/algorithm/max_element
  */
 template <typename ForwardIterator, typename BinaryPredicate>
-ForwardIterator max_element(ForwardIterator first, ForwardIterator last,
-                            BinaryPredicate comp);
-
+ForwardIterator max_element(ForwardIterator first, ForwardIterator last, BinaryPredicate comp);
 
 /*! \p minmax_element finds the smallest and largest elements in the range <tt>[first, last)</tt>.
  *  It returns a pair of iterators <tt>(imin, imax)</tt> where \c imin is the same iterator
@@ -608,9 +601,9 @@ ForwardIterator max_element(ForwardIterator first, ForwardIterator last,
  *          if it is not an empty range; \p last, otherwise.
  *
  *  \tparam DerivedPolicy The name of the derived execution policy.
- *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward Iterator</a>,
- *          and \c ForwardIterator's \c value_type is a model of
- *          <a href="https://en.cppreference.com/w/cpp/named_req/LessThanComparable">LessThan Comparable</a>.
+ *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward
+ * Iterator</a>, and \c ForwardIterator's \c value_type is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/LessThanComparable">LessThan Comparable</a>.
  *
  *  \code
  *  #include <thrust/extrema.h>
@@ -629,10 +622,9 @@ ForwardIterator max_element(ForwardIterator first, ForwardIterator last,
  *  \see max_element
  *  \see http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2005/n1840.pdf
  */
-template<typename DerivedPolicy, typename ForwardIterator>
-THRUST_HOST_DEVICE
-thrust::pair<ForwardIterator,ForwardIterator> minmax_element(const thrust::detail::execution_policy_base<DerivedPolicy> &exec, ForwardIterator first, ForwardIterator last);
-
+template <typename DerivedPolicy, typename ForwardIterator>
+THRUST_HOST_DEVICE thrust::pair<ForwardIterator, ForwardIterator> minmax_element(
+  const thrust::detail::execution_policy_base<DerivedPolicy>& exec, ForwardIterator first, ForwardIterator last);
 
 /*! \p minmax_element finds the smallest and largest elements in the range <tt>[first, last)</tt>.
  *  It returns a pair of iterators <tt>(imin, imax)</tt> where \c imin is the same iterator
@@ -644,9 +636,9 @@ thrust::pair<ForwardIterator,ForwardIterator> minmax_element(const thrust::detai
  *  \return A pair of iterator pointing to the smallest and largest elements of the range <tt>[first, last)</tt>,
  *          if it is not an empty range; \p last, otherwise.
  *
- *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward Iterator</a>,
- *          and \c ForwardIterator's \c value_type is a model of
- *          <a href="https://en.cppreference.com/w/cpp/named_req/LessThanComparable">LessThan Comparable</a>.
+ *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward
+ * Iterator</a>, and \c ForwardIterator's \c value_type is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/LessThanComparable">LessThan Comparable</a>.
  *
  *  \code
  *  #include <thrust/extrema.h>
@@ -665,9 +657,7 @@ thrust::pair<ForwardIterator,ForwardIterator> minmax_element(const thrust::detai
  *  \see http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2005/n1840.pdf
  */
 template <typename ForwardIterator>
-thrust::pair<ForwardIterator,ForwardIterator> minmax_element(ForwardIterator first, 
-                                                             ForwardIterator last);
-
+thrust::pair<ForwardIterator, ForwardIterator> minmax_element(ForwardIterator first, ForwardIterator last);
 
 /*! \p minmax_element finds the smallest and largest elements in the range <tt>[first, last)</tt>.
  *  It returns a pair of iterators <tt>(imin, imax)</tt> where \c imin is the same iterator
@@ -684,10 +674,10 @@ thrust::pair<ForwardIterator,ForwardIterator> minmax_element(ForwardIterator fir
  *          if it is not an empty range; \p last, otherwise.
  *
  *  \tparam DerivedPolicy The name of the derived execution policy.
- *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward Iterator</a>,
- *          and \p ForwardIterator's \c value_type is convertible to both \p comp's
- *          \c first_argument_type and \c second_argument_type.
- *  \tparam BinaryPredicate is a model of <a href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">Binary Predicate</a>.
+ *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward
+ * Iterator</a>, and \p ForwardIterator's \c value_type is convertible to both \p comp's \c first_argument_type and \c
+ * second_argument_type. \tparam BinaryPredicate is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">Binary Predicate</a>.
  *
  *  The following code snippet demonstrates how to use \p minmax_element to find the smallest and largest elements
  *  of a collection of key-value pairs using the \p thrust::host execution policy for parallelization:
@@ -716,7 +706,8 @@ thrust::pair<ForwardIterator,ForwardIterator> minmax_element(ForwardIterator fir
  *  ...
  *  key_value data[4] = { {4,5}, {0,7}, {2,3}, {6,1} };
  *
- *  thrust::pair<key_value*,key_value*> extrema = thrust::minmax_element(thrust::host, data, data + 4, compare_key_value());
+ *  thrust::pair<key_value*,key_value*> extrema = thrust::minmax_element(thrust::host, data, data + 4,
+ * compare_key_value());
  *
  *  // extrema.first   == data + 1
  *  // *extrema.first  == {0,7}
@@ -728,10 +719,12 @@ thrust::pair<ForwardIterator,ForwardIterator> minmax_element(ForwardIterator fir
  *  \see max_element
  *  \see http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2005/n1840.pdf
  */
-template<typename DerivedPolicy, typename ForwardIterator, typename BinaryPredicate>
-THRUST_HOST_DEVICE
-thrust::pair<ForwardIterator,ForwardIterator> minmax_element(const thrust::detail::execution_policy_base<DerivedPolicy> &exec, ForwardIterator first, ForwardIterator last, BinaryPredicate comp);
-
+template <typename DerivedPolicy, typename ForwardIterator, typename BinaryPredicate>
+THRUST_HOST_DEVICE thrust::pair<ForwardIterator, ForwardIterator> minmax_element(
+  const thrust::detail::execution_policy_base<DerivedPolicy>& exec,
+  ForwardIterator first,
+  ForwardIterator last,
+  BinaryPredicate comp);
 
 /*! \p minmax_element finds the smallest and largest elements in the range <tt>[first, last)</tt>.
  *  It returns a pair of iterators <tt>(imin, imax)</tt> where \c imin is the same iterator
@@ -744,10 +737,10 @@ thrust::pair<ForwardIterator,ForwardIterator> minmax_element(const thrust::detai
  *  \return A pair of iterator pointing to the smallest and largest elements of the range <tt>[first, last)</tt>,
  *          if it is not an empty range; \p last, otherwise.
  *
- *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward Iterator</a>,
- *          and \p ForwardIterator's \c value_type is convertible to both \p comp's
- *          \c first_argument_type and \c second_argument_type.
- *  \tparam BinaryPredicate is a model of <a href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">Binary Predicate</a>.
+ *  \tparam ForwardIterator is a model of <a href="https://en.cppreference.com/w/cpp/iterator/forward_iterator">Forward
+ * Iterator</a>, and \p ForwardIterator's \c value_type is convertible to both \p comp's \c first_argument_type and \c
+ * second_argument_type. \tparam BinaryPredicate is a model of <a
+ * href="https://en.cppreference.com/w/cpp/named_req/BinaryPredicate">Binary Predicate</a>.
  *
  *  The following code snippet demonstrates how to use \p minmax_element to find the smallest and largest elements
  *  of a collection of key-value pairs.
@@ -787,9 +780,8 @@ thrust::pair<ForwardIterator,ForwardIterator> minmax_element(const thrust::detai
  *  \see http://www.open-std.org/jtc1/sc22/wg21/docs/papers/2005/n1840.pdf
  */
 template <typename ForwardIterator, typename BinaryPredicate>
-thrust::pair<ForwardIterator,ForwardIterator> minmax_element(ForwardIterator first, 
-                                                             ForwardIterator last,
-                                                             BinaryPredicate comp);
+thrust::pair<ForwardIterator, ForwardIterator>
+minmax_element(ForwardIterator first, ForwardIterator last, BinaryPredicate comp);
 
 /*! \} // end extrema
  *  \} // end reductions
