@@ -21,8 +21,6 @@
 #pragma once
 
 #include <thrust/detail/config.h>
-#include <thrust/detail/cpp11_required.h>
-
 
 #include <thrust/mr/disjoint_pool.h>
 
@@ -44,23 +42,20 @@ namespace mr
  *  \param upstream the first argument to the constructor, if invoked
  *  \param bookkeeper the second argument to the constructor, if invoked
  */
-template<typename Upstream, typename Bookkeeper>
-THRUST_HOST 
-thrust::mr::disjoint_unsynchronized_pool_resource<Upstream, Bookkeeper> & tls_disjoint_pool(
-    Upstream * upstream = NULL,
-    Bookkeeper * bookkeeper = NULL)
+template <typename Upstream, typename Bookkeeper>
+THRUST_HOST thrust::mr::disjoint_unsynchronized_pool_resource<Upstream, Bookkeeper>&
+tls_disjoint_pool(Upstream* upstream = nullptr, Bookkeeper* bookkeeper = nullptr)
 {
-    static thread_local auto adaptor = [&]{
-        assert(upstream && bookkeeper);
-        return thrust::mr::disjoint_unsynchronized_pool_resource<Upstream, Bookkeeper>(upstream, bookkeeper);
-    }();
+  static thread_local auto adaptor = [&] {
+    assert(upstream && bookkeeper);
+    return thrust::mr::disjoint_unsynchronized_pool_resource<Upstream, Bookkeeper>(upstream, bookkeeper);
+  }();
 
-    return adaptor;
+  return adaptor;
 }
 
 /*! \}
  */
 
-} // end mr
+} // namespace mr
 THRUST_NAMESPACE_END
-
